==> enterprisemodules-wls_config-3.3.8.tar.gz: enterprisemodules-wls_config-3.3.8/lib/puppet/type/wls_saf_remote_context.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_saf_remote_context) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-EOD
    This resource allows you to manage a SAF remote contexts in a JMS Module of a WebLogic domain.

    Here is an example on how you should use this:

        wls_saf_remote_context { 'jmsClusterModule:RemoteSAFContext-0':
          ensure        => 'present',
          connect_url   => 't3://10.10.10.10:7001',
          weblogic_user => 'weblogic',
          weblogic_password => 'weblogic1',
        }

    In this example you are managing a SAF remote contexts in the default domain. When you want to
    manage a SAF remote contexts in a specific domain, you can use:

        wls_saf_remote_context { 'my_domain/jmsClusterModule:RemoteSAFContext-1':
          ensure      => 'present',
          connect_url => 't3://10.10.10.10:7001',
        }

    EOD

    bean_path('/JMSSystemResources/%{jmsmodule}/JMSResource/%{jmsmodule}/SAFRemoteContexts')
    bean_type('SAFRemoteContext')

    ensurable
    parameter :remote_context_name
    parameter :domain
    parameter :name
    parameter :jmsmodule
    parameter :timeout

    property :weblogic_password
    property :weblogic_user
    property :connect_url
    extraproperties do
      property :login_password
      property :login_url
      property :login_username
      property :reply_to_saf_remote_context_name
      property :compression_threshold
      property :notes
      #
      # Weblogic 12.2.1 new properties
      #
    end

    add_title_attributes(:jmsmodule, :remote_context_name) do
      /(.+):(.+)/
    end
  end
end

==> enterprisemodules-wls_config-3.12.2.tar.gz: enterprisemodules-wls_config-3.12.2/lib/puppet/type/wls_saf_remote_context.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_saf_remote_context) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-DESC
    This resource allows you to manage a SAF remote contexts in a JMS Module of a WebLogic domain.

    Here is an example on how you should use this:

        wls_saf_remote_context { 'jmsClusterModule:RemoteSAFContext-0':
          ensure        => 'present',
          connect_url   => 't3://10.10.10.10:7001',
          weblogic_user => 'weblogic',
          weblogic_password => 'weblogic1',
        }

    In this example you are managing a SAF remote contexts in the default domain. When you want to
    manage a SAF remote contexts in a specific domain, you can use:

        wls_saf_remote_context { 'my_domain/jmsClusterModule:RemoteSAFContext-1':
          ensure      => 'present',
          connect_url => 't3://10.10.10.10:7001',
        }

    DESC

    bean_path('/JMSSystemResources/%<jmsmodule>s/JMSResource/%<jmsmodule>s/SAFRemoteContexts')
    bean_type('SAFRemoteContext')

    ensurable
    parameter :remote_context_name
    parameter :domain
    parameter :name
    parameter :jmsmodule
    parameter :timeout

    property :weblogic_password
    property :weblogic_user
    property :connect_url
    extraproperties do
      property :login_password
      property :login_url
      property :login_username
      property :reply_to_saf_remote_context_name
      property :compression_threshold
      property :notes
      #
      # Weblogic 12.2.1 new properties
      #
    end

    add_title_attributes(:jmsmodule, :remote_context_name) do
      /(.+):(.+)/
    end
  end
end
